@@ -20,12 +20,15 @@ our $keep = '';
 
 sub perlversion {
   my $DEBUGGING = ($Config{ccflags} =~ m/-DDEBUGGING/);
-  return sprintf("%1.6f%s%s%s", $],
+  my $dVAR = ($Config{ccflags} =~ m/-DPERL_GLOBAL_STRUCT/);
+  return sprintf("%1.6f%s%s%s%s", $],
                  ($Config{usecperl} ? "c" : ""),
                  ($DEBUGGING ? 'd' : ''),
                  ($Config{useithreads} ? ''
                   : $Config{usemultiplicity} ? '-m'
-                  : '-nt'));
+                  : '-nt'),
+                 ($dVAR ? '-dVAR' : '')
+                 );
 }
 
 sub percent {
@@ -107,7 +110,7 @@ sub get_module_list {
   close F;
   @modules = grep {s/\s+//g;!/^#/} split /\n/, $s;
 
-  diag "scanning installed modules";
+  diag "scanning installed modules" unless $ENV{PERL_CORE};
   for my $m (@modules) {
     # redirect stderr
     open (SAVEOUT, ">&STDERR");
